% Function for calculating the trajectory of a particle. The frequency will
% be automatically adjusted to the nearest matching half-wavelength and 
% returned as fAdj
%
% Author: Per Augustsson
%
% Last edited: 2014-12-09 

function [x, y, t, fAdj] = acoustopath(varargin)

% Assign default values to parameters
freq=2e6;               % frequency [Hz]
Eac=3.69;               % acoustic energy density J/m^3
c_m=1508;               % speed of sound in medium [m/s]
rho_m=1010;             % density of medium [kg/m^3]
ny=1e-3;                % viscosity of medoium [Pa*s]
Q=100/6e10;             % Flow rate [m^3/s] (Example: 500/6e10 -> 500 L/min)
W=375e-6;               % Channel width [m]
H=150e-6;               % Channel height [m]
a=5e-6/2;               % Particle radius [m]
rho_p=1050;             % Density of particle [m^3/s]
c_p=2400;               % Speed of sound of particle [m/s]
x_start=0;              % Particle's starting position along x [m]
y_start=5e-6;           % Particle's starting position along y [m]
z_start=75e-6;          % Particle's starting position along z [m]
N_iter=7;               % Number of iterations for poiseuille flow (7 is good)
N=1000;                 % Number of elements in output vector
time=100;               % Maximum timepoint in trajectory 

% Assign values to variabled passed along to the function
for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'frequency'
            freq=varargin{i+1};
        case 'energy'
            Eac=varargin{i+1};
        case 'c_m'
            c_m=varargin{i+1};
        case 'rho_m'
            rho_m=varargin{i+1};
        case 'viscosity'
            ny=varargin{i+1};
        case 'flow'
            Q=varargin{i+1};
        case 'width'
            W=varargin{i+1};
        case 'height'
            H=varargin{i+1};
        case 'radius'
            a=varargin{i+1};
        case 'rho_p'
            rho_p=varargin{i+1};
        case 'c_p'
            c_p=varargin{i+1};
        case 'x_start'
            x_start=varargin{i+1};
        case 'y_start'
            y_start=varargin{i+1};
        case 'z_start'
            z_start=varargin{i+1};
        case 'n_iter'
            N_iter=varargin{i+1};
        case 'time'
            time=varargin{i+1};
        case 'veclength'
            N=varargin{i+1};
    end
end

% Adjust the frequency and lambda to the nearest matching resonance
% wavelength according to the given speed of sound and frequency
lambda = c_m/freq;

% Calculate the nearest number of half wavelengths
n = round(W/(lambda/2));

% Adjust the wavelength to fit the channel width
lambdaAdj = 2*W/n;

% Calculate the adjusted matching frequency to return to caller 
fAdj = c_m/lambdaAdj;

% Calculate the wave vector
k=2*pi/lambdaAdj;

% Calculate the compressibilities of the particle (p) and medium (m)
K_p=1/(rho_p*c_p^2);
K_m=1/(rho_m*c_m^2);

% Calculate the relative compressibility and density of the particle 
K_tilde=K_p/K_m;
rho_tilde=rho_p/rho_m;

% Calculate the acoustic contrast of the particle in this medium
f1=1-K_tilde;
f2=(2*rho_tilde-2)/(2*rho_tilde+1);
phi = f1/3 + f2/2;

% Generate vector of time points
t=time*(0:1/(N-1):1);

% Calculate particles position vs time (Eac is divided by two to accomodate
% for longitudinal modes)
y=1/k*atan(tan(k*y_start)*exp(4*phi*(k*a)^2/(3*ny)*Eac*t));

% Take care of shift of sign when using atan()
if y_start>W/2
    y=y+W;
end

% Calculate x-axis flow velocities for all y- and z- positions in the
% trajectory
vx = poiseuille(Q, W, H, N_iter, y, z_start);

% Calculate the x-positions based on the x-velocities
x=[x_start cumsum(vx*time/(N-1),2)];
% Trim x to same length as y and t.
x(end)=[];
